Package: pct
Type: Package
Title: Propensity to Cycle Tool
Version: 0.10.0
Authors@R: c(
    person("Robin", "Lovelace", email = "rob00x@gmail.com", role = c("aut", "cre"),
      comment = c(ORCID = "0000-0001-5679-6536")),
    person("Layik", "Hama", email = "layik.hama@gmail.com", role = c("aut"),
      comment = c(ORCID = "0000-0003-1912-4890")),
    person("Nathanael", "Sheehan", role = c("ctb"),
      comment = c(ORCID = "0000-0002-2779-0976"))
    )
Description: Functions and example data to teach and
  increase the reproducibility of the methods and code underlying 
  the Propensity to Cycle Tool (PCT), a research project and web application 
  hosted at <https://www.pct.bike/>. 
  For an academic paper on the methods,
  see Lovelace et al (2017) <doi:10.5198/jtlu.2016.862>.
Depends: R (>= 3.5.0)
License: GPL-3
URL: https://itsleeds.github.io/pct/, https://github.com/ITSLeeds/pct
BugReports: https://github.com/ITSLeeds/pct/issues
Encoding: UTF-8
LazyData: true
Imports: boot, stplanr (>= 0.2.8), readr, sf, crul
Suggests: covr, curl, dplyr, ggplot2, knitr, leaflet, pbapply, remotes,
        rmarkdown, tmap, bookdown
VignetteBuilder: knitr
RoxygenNote: 7.2.3
Language: en-GB
NeedsCompilation: no
Packaged: 2025-03-04 23:38:32 UTC; robin
Author: Robin Lovelace [aut, cre] (<https://orcid.org/0000-0001-5679-6536>),
  Layik Hama [aut] (<https://orcid.org/0000-0003-1912-4890>),
  Nathanael Sheehan [ctb] (<https://orcid.org/0000-0002-2779-0976>)
Maintainer: Robin Lovelace <rob00x@gmail.com>
Repository: CRAN
Date/Publication: 2025-03-05 08:40:07 UTC
Built: R 4.6.0; ; 2026-04-29 23:40:20 UTC; unix
