# Generated by roxygen2: do not edit by hand

export(get_centroids_ew)
export(get_desire_lines)
export(get_od)
export(get_pct)
export(get_pct_centroids)
export(get_pct_lines)
export(get_pct_rnet)
export(get_pct_routes_fast)
export(get_pct_routes_quiet)
export(get_pct_zones)
export(model_pcycle_pct_2020)
export(uptake_pct_ebike_2020)
export(uptake_pct_godutch)
export(uptake_pct_godutch_2020)
export(uptake_pct_godutch_school2)
export(uptake_pct_govtarget)
export(uptake_pct_govtarget_2020)
export(uptake_pct_govtarget_school2)
